@@ -26,7 +26,6 @@ class QListViewItem;
 class QPopupMenu;
 class QStringList;
 class KDialogBase;
-class KDirWatch;
 class CustomProjectWidget;
 class Context;
 class KSelectAction;
@@ -62,18 +61,18 @@ public:
     virtual QString debugArguments() const;
     virtual QString runArguments() const;
     virtual DomUtil::PairList runEnvironmentVars() const;
+    QString relativeToProject( const QString& ) const;
 
 
 private slots:
     void populateProject();
-    void slotDirDirty( const QString& dir );
     void projectConfigWidget( KDialogBase *dlg );
     void contextMenu( QPopupMenu *popup, const Context *context );
     void slotAddToProject();
     void slotRemoveFromProject();
     void slotAddToProjectRecursive();
     void slotRemoveFromProjectRecursive();
-    void addNewFilesToProject();
+    void addNewFilesToProject( const QStringList& );
     void slotChangeBlacklist();
     void slotChooseActiveDirectory();
     void slotBuild();
@@ -101,8 +100,6 @@ private:
     bool isInBlacklist( const QString& ) const;
     void cleanFileList();
     void setFiletypes( const QStringList& );
-    QString relativeToProject( const QString& ) const;
-    void addDirWatches( const QString& );
     void findNewFiles( const QString& dir, QStringList& list) const;
 
     QStringList filetypes() const;
@@ -115,11 +112,26 @@ private:
     void putEnvVarsInVarMap();
     void switchBlacklistEntry(const QString& );
 
+    bool isInProject( const QString& fileName ) const;
+    void addToProject( const QString& fileName );
+    void removeFromProject( const QString& fileName );
+
+    /**
+     * @brief Set of all the project's files.
+     *
+     * @bug
+     * Due to deficiency in QT3,
+     * we have to use a map with next-to-useless element value,
+     * keyed by the file name,
+     * as a set-container replacement.
+     */
+    typedef QMap<QString, bool> ProjectFilesSet;
+
     QString m_projectDirectory;
     QString m_projectName;
     QString m_filelistDir;
-    QStringList m_sourceFiles;
-    QStringList m_autoAddFiles;
+    /** All the sources (files and directories) of this project. */
+    ProjectFilesSet m_sourceFilesSet;
     QPopupMenu *m_targetMenu;
     QPopupMenu *m_targetObjectFilesMenu;
     QPopupMenu *m_targetOtherFilesMenu;
@@ -140,7 +152,6 @@ private:
     QMap<QString, QString> m_makefileVars;
     bool m_recursive;
     bool m_first_recursive;
-    KDirWatch* dirwatch;
 };
 
 #endif
