@@ -319,8 +319,8 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
     }
     else
     {
-        myProjectItem->addValue( "CONFIG", "warn_on" );
-        myProjectItem->removeValue( "CONFIG", "warn_off" );
+        myProjectItem->addValue( "CONFIG", "warn_off" );
+        myProjectItem->removeValue( "CONFIG", "warn_on" );
     }
     if ( checkWindows->isChecked() )
         myProjectItem->addValue( "CONFIG", "windows" );
@@ -351,14 +351,14 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
             myProjectItem->addValue( "CONFIG", "dbus" );
         else
             myProjectItem->removeValue( "CONFIG", "dbus" );
-        if ( checkQtScript->isChecked() )
-            myProjectItem->addValue( "QT", "script" );
-        else
-            myProjectItem->removeValue( "QT", "script" );
         if ( checkBuildAll->isChecked() )
             myProjectItem->addValue( "CONFIG", "build_all" );
         else
             myProjectItem->removeValue( "CONFIG", "build_all" );
+        if ( checkQtHelp->isChecked() )
+            myProjectItem->addValue( "CONFIG", "help" );
+        else
+            myProjectItem->removeValue( "CONFIG", "help" );
 
         if ( checkQt4Core->isChecked() )
             myProjectItem->addValue( "QT", "core" );
@@ -392,6 +392,22 @@ void ProjectConfigurationDlg::updateProjectConfiguration()
             myProjectItem->addValue( "QT", "opengl" );
         else
             myProjectItem->removeValue( "QT", "opengl" );
+        if ( checkQtScript->isChecked() )
+            myProjectItem->addValue( "QT", "script" );
+        else
+            myProjectItem->removeValue( "QT", "script" );
+        if ( checkQtWebKit->isChecked() )
+            myProjectItem->addValue( "QT", "webkit" );
+        else
+            myProjectItem->removeValue( "QT", "webkit" );
+        if ( checkQtXmlPatterns->isChecked() )
+            myProjectItem->addValue( "QT", "xmlpatterns" );
+        else
+            myProjectItem->removeValue( "QT", "xmlpatterns" );
+        if ( checkPhonon->isChecked() )
+            myProjectItem->addValue( "QT", "phonon" );
+        else
+            myProjectItem->removeValue( "QT", "phonon" );
     }
 
     QStringList confValues = myProjectItem->scope->variableValues( "CONFIG" );
@@ -813,6 +829,10 @@ void ProjectConfigurationDlg::updateControls()
             checkBuildAll->setChecked( true );
         else
             checkBuildAll->setChecked( false );
+        if ( configValues.findIndex( "help" ) != -1 )
+            checkQtHelp->setChecked( true );
+        else
+            checkQtHelp->setChecked( false );
 
         QStringList qtLibs = myProjectItem->scope->variableValues( "QT" );
         if ( qtLibs.findIndex( "core" ) != -1 )
@@ -851,6 +871,18 @@ void ProjectConfigurationDlg::updateControls()
             checkQtScript->setChecked( true );
         else
             checkQtScript->setChecked( false );
+        if ( qtLibs.findIndex( "phonon" ) != -1 )
+            checkPhonon->setChecked( true );
+        else
+            checkPhonon->setChecked( false );
+        if ( qtLibs.findIndex( "webkit" ) != -1 )
+            checkQtWebKit->setChecked( true );
+        else
+            checkQtWebKit->setChecked( false );
+        if ( qtLibs.findIndex( "xmlpatterns" ) != -1 )
+            checkQtXmlPatterns->setChecked( true );
+        else
+            checkQtXmlPatterns->setChecked( false );
 
         checkDebugReleaseMode->setEnabled( true );
         checkBuildAll->setEnabled( true );
