@@ -336,8 +336,15 @@ QString QMakeScopeItem::relativePath()
     if( !scope || !scope->parent() )
         return "";
     if( scope->scopeType() == Scope::ProjectScope )
-        return URLUtil::getRelativePath( m_widget->projectDirectory(), scope->projectDir() );
-    else
+    {
+        if( scope->parent() && scope->parent()->variableValues("SUBDIRS").contains( URLUtil::relativePathToFile( scope->parent()->projectDir(), scope->projectDir()+"/"+scope->fileName() ) ) )
+        {
+            return URLUtil::relativePathToFile( scope->parent()->projectDir(), scope->projectDir()+"/"+scope->fileName() );
+        }else
+        {
+            return URLUtil::getRelativePath( m_widget->projectDirectory(), scope->projectDir() );
+        }
+    }else
         return static_cast<QMakeScopeItem*>( parent() ) ->relativePath();
 //     if( !scope->parent() )
 //         return "";
@@ -388,12 +395,14 @@ QString QMakeScopeItem::getSharedLibAddObject( QString basePath )
 QString QMakeScopeItem::getApplicationObject( QString basePath )
 {
     QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
-    if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
+    QString destdir = scope->resolveVariables( scope->variableValues( "DESTDIR" ).front() );
+
+    if ( !destdir.isEmpty() )
     {
-        if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
-            tmpPath += QString( QChar( QDir::separator() ) ) + scope->variableValues( "DESTDIR" ).front();
+        if ( QDir::isRelativePath( destdir ) )
+            tmpPath += QString( QChar( QDir::separator() ) ) + destdir;
         else
-            tmpPath = scope->variableValues( "DESTDIR" ).front();
+            tmpPath = destdir;
     }
     else
     {
@@ -402,19 +411,22 @@ QString QMakeScopeItem::getApplicationObject( QString basePath )
 
     tmpPath = QDir::cleanDirPath( tmpPath );
 
-    if ( scope->variableValues( "TARGET" ).front().isEmpty() )
+    QString target = scope->resolveVariables( scope->variableValues( "TARGET" ).front() );
+
+    if ( target.isEmpty() )
         return tmpPath + QString( QChar( QDir::separator() ) ) + scope->projectName();
     else
-        return tmpPath + QString( QChar( QDir::separator() ) ) + scope->variableValues( "TARGET" ).front();
+        return tmpPath + QString( QChar( QDir::separator() ) ) + target;
 }
 
 QString QMakeScopeItem::getLibAddObject( QString basePath )
 {
     if ( scope->variableValues( "CONFIG" ).findIndex( "dll" ) != -1 )
     {
-        if ( !scope->variableValues( "TARGET" ).front().isEmpty() )
+        QString target = scope->resolveVariables( scope->variableValues( "TARGET" ).front() );
+        if ( !target.isEmpty() )
         {
-            return ( "-l" + scope->variableValues( "TARGET" ).front() );
+            return ( "-l" + target );
         }
         else
         {
@@ -425,12 +437,13 @@ QString QMakeScopeItem::getLibAddObject( QString basePath )
             || scope->variableValues("TEMPLATE").findIndex("lib") != -1 )
     {
         QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
-        if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
+        QString destdir = scope->resolveVariables( scope->variableValues( "DESTDIR" ).front() );
+        if ( !destdir.isEmpty() )
         {
-            if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
-                tmpPath += QString( QChar( QDir::separator() ) ) + scope->variableValues( "DESTDIR" ).front();
+            if ( QDir::isRelativePath( destdir ) )
+                tmpPath += QString( QChar( QDir::separator() ) ) + destdir;
             else
-                tmpPath = scope->variableValues( "DESTDIR" ).front();
+                tmpPath = destdir;
         }
         else
         {
@@ -440,9 +453,10 @@ QString QMakeScopeItem::getLibAddObject( QString basePath )
         tmpPath = QDir::cleanDirPath( tmpPath );
 
         QString libString;
-        if ( !scope->variableValues( "TARGET" ).front().isEmpty() )
+        QString target = scope->resolveVariables( scope->variableValues( "TARGET" ).front() );
+        if ( !target.isEmpty() )
         {
-            libString = tmpPath + QString( QChar( QDir::separator() ) ) + "lib" + scope->variableValues( "TARGET" ).front() + ".a";
+            libString = tmpPath + QString( QChar( QDir::separator() ) ) + "lib" + target + ".a";
 
         }
         else
@@ -462,12 +476,13 @@ QString QMakeScopeItem::getLibAddPath( QString basePath )
     if ( scope->variableValues( "CONFIG" ).findIndex( "dll" ) == -1 ) return ( "" );
 
     QString tmpPath = URLUtil::getRelativePath(basePath, scope->projectDir() );
-    if ( !scope->variableValues( "DESTDIR" ).front().isEmpty() )
+    QString destdir = scope->resolveVariables( scope->variableValues( "DESTDIR" ).front() );
+    if ( !destdir.isEmpty() )
     {
-        if ( QDir::isRelativePath( scope->variableValues( "DESTDIR" ).front() ) )
-            tmpPath += QString( QChar( QDir::separator() ) ) + scope->variableValues( "DESTDIR" ).front();
+        if ( QDir::isRelativePath( destdir ) )
+            tmpPath += QString( QChar( QDir::separator() ) ) + destdir;
         else
-            tmpPath = scope->variableValues( "DESTDIR" ).front();
+            tmpPath = destdir;
     }
     else
     {
@@ -566,6 +581,10 @@ FileItem* QMakeScopeItem::createFileItem( const QString& name )
         if  ( dirSepPos != - 1 )
             display = name.mid( dirSepPos + 1 );
     }
+    if( !m_widget->showVariablesInTree() )
+    {
+        display = scope->resolveVariables( display );
+    }
     FileItem * fitem = new FileItem( listView(), display );
     listView() ->takeItem( fitem );
 
@@ -759,18 +778,28 @@ void QMakeScopeItem::updateValues( const QString& var, const QStringList& values
         if ( values.findIndex( *it ) == -1 )
         {
             if( scopeValues.findIndex( *it ) != -1 )
+            {
                 scope->removeFromPlusOp( var, QStringList( *it ) );
-            else
+                scopeValues.remove( *it );
+            }else
                 scope->addToMinusOp( var, QStringList( *it ) );
         }
     }
     for( QStringList::const_iterator it = values.begin(); it != values.end(); ++it )
     {
-        if ( curValues.findIndex( *it ) == -1 )
+        if ( scopeValues.findIndex( *it ) != -1 )
         {
-            scope->addToPlusOp( var, QStringList( *it ) );
+            scopeValues.remove(*it);
         }
     }
+//     kdDebug(9024) << "--------------" << var << "------------------" << endl;
+//     kdDebug(9024) << "values: " << values << "| scope:" << scopeValues << endl;
+    scopeValues += values;
+//     kdDebug(9024) << "values: " << values << "| scope:" << scopeValues << endl;
+    scope->setPlusOp( var, scopeValues );
+//     QStringList tmp = scope->variableValuesForOp( var, "+=" );
+//     kdDebug(9024) << "result:" << tmp << endl;
+//     kdDebug(9024) << "---------------------------------------" << endl;
 }
 
 QMakeScopeItem* QMakeScopeItem::projectFileItem()
