@@ -33,10 +33,10 @@
 
 const QStringList Scope::KnownVariables = QStringList() << "QT" << "CONFIG" << "TEMPLATE" << "SUBDIRS" << "VERSION" << "LIBS" << "target.path" << "INSTALLS" << "MAKEFILE" << "TARGETDEPS" << "INCLUDEPATH" << "TARGET" << "DESTDIR" << "DEFINES" << "QMAKE_CXXFLAGS_DEBUG" << "QMAKE_CXXFLAGS_RELEASE" << "OBJECTS_DIR" << "UI_DIR" << "MOC_DIR" << "IDL_COMPILER" << "IDL_OPTIONS" << "RCC_DIR" << "IDLS" << "RESOURCES" << "IMAGES" << "LEXSOURCES" << "DISTFILES" << "YACCSOURCES" << "TRANSLATIONS" << "HEADERS" << "SOURCES" << "INTERFACES" << "FORMS" ;
 
-const QStringList Scope::KnownConfigValues = QStringList() << "debug" << "release" << "debug_and_release" << "warn_on" << "warn_off" << "staticlib" << "dll" << "plugin" << "designer" << "create_pkgconf" << "create_libtool" << "qt" << "console" << "windows" << "x11" << "thread" << "exceptions" << "stl" << "rtti" << "opengl" << "thread" << "ordered" << "precompile_header" << "qtestlib" << "uitools" << "dbus" << "assistant" << "build_all";
+const QStringList Scope::KnownConfigValues = QStringList() << "debug" << "release" << "debug_and_release" << "warn_on" << "warn_off" << "staticlib" << "dll" << "plugin" << "designer" << "create_pkgconf" << "create_libtool" << "qt" << "console" << "windows" << "x11" << "thread" << "exceptions" << "stl" << "rtti" << "opengl" << "thread" << "ordered" << "precompile_header" << "qtestlib" << "uitools" << "dbus" << "assistant" << "build_all" << "help";
 
-Scope::Scope( const QString &filename, TrollProjectPart* part )
-    : m_root( 0 ), m_incast( 0 ), m_parent( 0 ), m_num(0), m_isEnabled( true ), m_part(part), m_defaultopts(0)
+Scope::Scope( const QMap<QString, QString>& env, const QString &filename, TrollProjectPart* part )
+    : m_root( 0 ), m_incast( 0 ), m_parent( 0 ), m_num(0), m_isEnabled( true ), m_part(part), m_defaultopts(0), m_environment( env )
 {
     if ( !loadFromFile( filename ) )
     {
@@ -80,19 +80,19 @@ Scope::~Scope()
 }
 
 // Simple/Function Scopes
-Scope::Scope( unsigned int num, Scope* parent, QMake::ProjectAST* scope,
+Scope::Scope( const QMap<QString, QString>& env, unsigned int num, Scope* parent, QMake::ProjectAST* scope,
               QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
     : m_root( scope ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( true ),
-        m_part(part), m_defaultopts(defaultopts)
+        m_part(part), m_defaultopts(defaultopts), m_environment( env )
 {
     init();
 }
 
 //Subdirs
-Scope::Scope( unsigned int num, Scope* parent, const QString& filename,
+Scope::Scope( const QMap<QString, QString>& env, unsigned int num, Scope* parent, const QString& filename,
               TrollProjectPart* part, bool isEnabled )
     : m_root( 0 ), m_incast( 0 ), m_parent( parent ), m_num(num), m_isEnabled( isEnabled ),
-    m_part(part), m_defaultopts(0)
+    m_part(part), m_defaultopts(0), m_environment( env )
 {
     if ( !loadFromFile( filename ) )
     {
@@ -114,10 +114,10 @@ Scope::Scope( unsigned int num, Scope* parent, const QString& filename,
 }
 
 //Include Scope
-Scope::Scope( unsigned int num, Scope* parent, QMake::IncludeAST* incast, const QString& path,
+Scope::Scope( const QMap<QString, QString>& env, unsigned int num, Scope* parent, QMake::IncludeAST* incast, const QString& path,
               const QString& incfile, QMakeDefaultOpts* defaultopts, TrollProjectPart* part )
     : m_root( 0 ), m_incast( incast ), m_parent( parent ), m_num(num), m_isEnabled( true ),
-    m_part(part), m_defaultopts(defaultopts)
+    m_part(part), m_defaultopts(defaultopts), m_environment( env )
 {
     QString absfilename;
     QString tmp = incfile.stripWhiteSpace();
@@ -155,8 +155,12 @@ bool Scope::loadFromFile( const QString& filename )
     if ( !QFileInfo(filename).exists() || QMake::Driver::parseFile( filename, &m_root, 0 ) != 0 )
     {
         kdDebug( 9024 ) << "Couldn't parse project: " << filename << endl;
-        KMessageBox::error( 0, i18n( "Couldn't parse project file: %1" ).arg( filename ),
-                i18n( "Couldn't parse project file" ) );
+        if( DomUtil::readBoolEntry( *m_part->projectDom(),
+            "/kdevtrollproject/qmake/showParseErrors", true ) )
+        {
+            KMessageBox::error( 0, i18n( "Couldn't parse project file: %1" ).arg( filename ),
+                    i18n( "Couldn't parse project file" ) );
+        }
         m_root = 0;
         return false;
     }
@@ -304,7 +308,7 @@ QStringList Scope::variableValuesForOp( const QString& variable , const QString&
     return result;
 }
 
-QStringList Scope::variableValues( const QString& variable, bool checkIncParent, bool fetchFromParent )
+QStringList Scope::variableValues( const QString& variable, bool checkIncParent, bool fetchFromParent, bool evaluateSubScopes )
 {
     QStringList result;
 
@@ -316,7 +320,7 @@ QStringList Scope::variableValues( const QString& variable, bool checkIncParent,
         return m_varCache[variable];
     }
 
-    calcValuesFromStatements( variable, result, checkIncParent, 0, fetchFromParent );
+    calcValuesFromStatements( variable, result, checkIncParent, 0, fetchFromParent, true, evaluateSubScopes );
     result = cleanStringList(result);
     if( ( scopeType() != Scope::IncludeScope || checkIncParent  ) && fetchFromParent )
     {
@@ -325,13 +329,13 @@ QStringList Scope::variableValues( const QString& variable, bool checkIncParent,
     return result;
 }
 
-void Scope::calcValuesFromStatements( const QString& variable, QStringList& result, bool checkIncParent, QMake::AST* stopHere, bool fetchFromParent ) const
+void Scope::calcValuesFromStatements( const QString& variable, QStringList& result, bool checkIncParent, QMake::AST* stopHere, bool fetchFromParent, bool setDefault, bool evaluateSubScopes ) const
 {
     if( !m_root )
         return;
 
     /* For variables that we don't know and which are not QT/CONFIG find the default value */
-    if( m_defaultopts
+    if( setDefault && m_defaultopts
         && m_defaultopts->variables().findIndex(variable) != -1
         && ( variable == "TEMPLATE" || variable == "QT" || KnownVariables.findIndex(variable) == -1 || variable == "CONFIG" ) )
     {
@@ -340,11 +344,11 @@ void Scope::calcValuesFromStatements( const QString& variable, QStringList& resu
 
     if ( ( scopeType() == FunctionScope || scopeType() == SimpleScope ) && fetchFromParent )
     {
-        m_parent->calcValuesFromStatements( variable, result, checkIncParent, this->m_root );
+        m_parent->calcValuesFromStatements( variable, result, checkIncParent, this->m_root, fetchFromParent, setDefault, evaluateSubScopes );
     }
     else if ( scopeType() == IncludeScope && checkIncParent && fetchFromParent )
     {
-        m_parent->calcValuesFromStatements( variable, result, true, this->m_incast );
+        m_parent->calcValuesFromStatements( variable, result, true, this->m_incast, fetchFromParent, setDefault, evaluateSubScopes );
     }
 
     QValueList<QMake::AST*>::const_iterator it;
@@ -379,6 +383,46 @@ void Scope::calcValuesFromStatements( const QString& variable, QStringList& resu
                     }
                 }
             }
+        }else if( evaluateSubScopes )
+        {
+            if( ast->nodeType() == QMake::AST::IncludeAST )
+            {
+                QMake::IncludeAST* iast = static_cast<QMake::IncludeAST*>(ast);
+                QValueList<unsigned int> l = m_scopes.keys();
+                for( unsigned int i = 0; i < l.count(); ++i )
+                {
+                    int num = l[ i ];
+                    if( m_scopes.contains( num ) )
+                    {
+                        Scope* s = m_scopes[num];
+                        if( s && s->scopeType() == IncludeScope && s->m_incast == iast )
+                        {
+                            s->calcValuesFromStatements( variable, result, false, 0, false, false,  evaluateSubScopes );
+                        }
+                    }
+                }
+
+            }
+            else if( ast->nodeType() == QMake::AST::ProjectAST )
+            {
+                QMake::ProjectAST* past = static_cast<QMake::ProjectAST*>(ast);
+                if( past->isFunctionScope() || past->isScope() )
+                {
+                    QValueList<unsigned int> l = m_scopes.keys();
+                    for( unsigned int i = 0; i < l.count(); ++i )
+                    {
+                        int num = l[ i ];
+                        if( m_scopes.contains( num ) )
+                        {
+                            Scope* s = m_scopes[num];
+                            if( s && s->m_root == past && s->m_root->scopedID == past->scopedID  )
+                            {
+                                s->calcValuesFromStatements( variable, result, false, 0, false, false, evaluateSubScopes );
+                            }
+                        }
+                    }
+                }
+            }
         }
     }
 
@@ -449,7 +493,7 @@ Scope* Scope::createFunctionScope( const QString& funcName, const QString& args
     ast->addChildAST( new QMake::NewLineAST() );
     m_root->addChildAST( ast );
     m_root->addChildAST( new QMake::NewLineAST() );
-    Scope* funcScope = new Scope( getNextScopeNum(), this, ast, m_defaultopts, m_part );
+    Scope* funcScope = new Scope( m_environment, getNextScopeNum(), this, ast, m_defaultopts, m_part );
     if( funcScope->scopeType() != Scope::InvalidScope )
     {
         m_scopes.insert( getNextScopeNum(), funcScope );
@@ -474,7 +518,7 @@ Scope* Scope::createSimpleScope( const QString& scopename )
     if ( m_part->isQt4Project() )
         addToPlusOp( "CONFIG", QStringList( scopename ) );
     */
-    Scope* simpleScope = new Scope( getNextScopeNum(), this, ast, m_defaultopts, m_part );
+    Scope* simpleScope = new Scope( m_environment, getNextScopeNum(), this, ast, m_defaultopts, m_part );
 
     if( simpleScope->scopeType() != Scope::InvalidScope )
     {
@@ -506,7 +550,7 @@ Scope* Scope::createIncludeScope( const QString& includeFile, bool negate )
     QMake::IncludeAST* ast = new QMake::IncludeAST();
     ast->setDepth( m_root->depth() );
     ast->projectName = includeFile;
-    Scope* incScope = new Scope( funcScope->getNextScopeNum(), funcScope, ast, projectDir(), resolveVariables( ast->projectName ), m_defaultopts, m_part );
+    Scope* incScope = new Scope( m_environment, funcScope->getNextScopeNum(), funcScope, ast, projectDir(), resolveVariables( ast->projectName ), m_defaultopts, m_part );
     if ( incScope->scopeType() != InvalidScope )
     {
         funcScope->m_root->addChildAST( ast );
@@ -557,7 +601,7 @@ Scope* Scope::createSubProject( const QString& projname )
 
         kdDebug( 9024 ) << "Creating subproject with filename:" << filename << endl;
 
-        Scope* s = new Scope( getNextScopeNum(), this, filename, m_part );
+        Scope* s = new Scope( m_environment, getNextScopeNum(), this, filename, m_part );
         s->loadDefaultOpts();
         if ( s->scopeType() != InvalidScope )
         {
@@ -650,6 +694,7 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
             Scope* project = m_scopes[ num ];
             if( !project )
                 return false;
+
             QString projdir = project->scopeName();
             if ( deleteSubdir )
             {
@@ -671,6 +716,10 @@ bool Scope::deleteSubProject( unsigned int num, bool deleteSubdir )
                         if( !projdir.rmdir( dir ) )
                             kdDebug( 9024 ) << "Couldn't delete " << dir << " from " << projdir.absPath() << endl;
                     }
+                }else
+                {
+                    QDir d( project->projectDir() );
+                    kdDebug(9024) << "removed subproject?:" << d.remove( dir ) << endl;
                 }
             }
             QValueList<QMake::AST*>::iterator foundit = findExistingVariable( "SUBDIRS" );
@@ -870,7 +919,6 @@ void Scope::init()
 
     kdDebug(9024) << "Initializing Scope: " << scopeName() << this << endl;
     m_maxCustomVarNum = 1;
-    m_unfinishedScopes = new QValueList<Scope*>();
 
     QValueList<QMake::AST*>::const_iterator it;
     for ( it = m_root->m_children.begin(); it != m_root->m_children.end(); ++it )
@@ -878,7 +926,7 @@ void Scope::init()
         if ( ( *it ) ->nodeType() == QMake::AST::ProjectAST )
         {
             QMake::ProjectAST * p = static_cast<QMake::ProjectAST*>( *it );
-            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, p, m_defaultopts, m_part ) );
+            m_scopes.insert( getNextScopeNum(), new Scope( m_environment, getNextScopeNum(), this, p, m_defaultopts, m_part ) );
         }
         else if ( ( *it ) ->nodeType() == QMake::AST::IncludeAST )
         {
@@ -888,7 +936,7 @@ void Scope::init()
             {
                 filename = resolveVariables(i->projectName, *it);
             }
-            m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this, i, projectDir(), filename, m_defaultopts, m_part ) );
+            m_scopes.insert( getNextScopeNum(), new Scope( m_environment, getNextScopeNum(), this, i, projectDir(), filename, m_defaultopts, m_part ) );
         }
         else if ( ( *it ) ->nodeType() == QMake::AST::AssignmentAST )
         {
@@ -912,7 +960,10 @@ void Scope::init()
                         projectfile = str;
                     }else
                     {
-                        subproject = QDir( projectDir() + QString( QChar( QDir::separator() ) ) + str,
+                        QString dir = str;
+                        if( QFileInfo( dir ).isRelative() )
+                            dir = projectDir() + QString( QChar( QDir::separator() ) ) + dir;
+                        subproject = QDir(  dir,
                                            "*.pro", QDir::Name | QDir::IgnoreCase, QDir::Files );
                         if( !subproject.exists() )
                         {
@@ -933,7 +984,7 @@ void Scope::init()
 
                     }
                     kdDebug( 9024 ) << "Parsing subproject: " << projectfile << endl;
-                    m_scopes.insert( getNextScopeNum(), new Scope( getNextScopeNum(), this,
+                    m_scopes.insert( getNextScopeNum(), new Scope( m_environment, getNextScopeNum(), this,
                                                 subproject.absFilePath( projectfile ),
                                          m_part, ( m->op != "-=" )) );
                 }
@@ -1111,8 +1162,8 @@ bool Scope::listsEqual(const QStringList& l1, const QStringList& l2)
 {
     QStringList left = l1;
     QStringList right = l2;
-    left.sort();
-    right.sort();
+//     left.sort();
+//     right.sort();
     return (left == right);
 }
 
@@ -1189,7 +1240,7 @@ Scope* Scope::disableSubproject( const QString& dir)
 
         kdDebug( 9024 ) << "Disabling subproject with filename:" << filename << endl;
 
-        Scope* s = new Scope( getNextScopeNum(), this, filename, m_part, false );
+        Scope* s = new Scope( m_environment, getNextScopeNum(), this, filename, m_part, false );
         addToMinusOp( "SUBDIRS", QStringList( dir ) );
         m_scopes.insert( getNextScopeNum(), s );
         return s;
@@ -1227,7 +1278,7 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
     QMap<QString, QStringList> variables;
     for( QStringList::iterator it = result.begin(); it != result.end(); ++it )
     {
-        QRegExp re("\\$\\$([^{}\\) /]*)( |\\\\)|/|$)");
+        QRegExp re("\\$\\$([^{}\\) /]*)( |\\)|/|$)");
         int pos = 0;
         while( pos >= 0 )
         {
@@ -1235,7 +1286,13 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
             if( pos > -1 )
             {
                 if( !variables.contains( re.cap(1) ) )
+                {
                     variables[re.cap(1)] = resolveVariables( variableValues( re.cap(1), stopHere ) );
+                    if( variables[re.cap(1)].isEmpty() && re.cap(1) == "TARGET" )
+                    {
+                        variables[re.cap(1)] = QFileInfo( fileName() ).baseName();
+                    }
+                }
                 pos += re.matchedLength();
             }
         }
@@ -1247,7 +1304,13 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
             if( pos > -1 )
             {
                 if( !variables.contains( re.cap(1) ) )
+                {
                     variables[re.cap(1)] = resolveVariables( variableValues( re.cap(1), stopHere ) );
+                    if( variables[re.cap(1)].isEmpty() && re.cap(1) == "TARGET" )
+                    {
+                        variables[re.cap(1)] = QFileInfo( fileName() ).baseName();
+                    }
+                }
                 pos += re.matchedLength();
             }
         }
@@ -1259,8 +1322,11 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
             pos = re.search( (*it), pos );
             if( pos > -1 )
             {
-                if( !envvars.contains( re.cap(1) ) && ::getenv( re.cap(1).local8Bit() ) != 0 )
-                    envvars[re.cap(1)] = QString::fromLocal8Bit(::getenv( re.cap(1).local8Bit() ) );
+                if( !envvars.contains( re.cap(1) ) )
+                    if( m_environment.contains( re.cap(1) ) != -1 )
+                        envvars[re.cap(1)] = m_environment[ re.cap(1) ];
+                    else if ( ::getenv( re.cap(1).local8Bit() ) != 0 )
+                        envvars[re.cap(1)] = QString::fromLocal8Bit( ::getenv( re.cap(1).local8Bit() ) );
                 pos += re.matchedLength();
             }
         }
