@@ -31,6 +31,8 @@
 #include <kaction.h>
 #include <kparts/part.h>
 #include <kprocess.h>
+#include <kconfig.h>
+#include <kapplication.h>
 #include <kurlrequesterdlg.h>
 #include <kurlrequester.h>
 #include <kurlcompletion.h>
@@ -258,6 +260,10 @@ QString TrollProjectPart::makeEnvironment()
          environstr += QString( "QTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + QString( " PATH=$QTDIR/bin:$PATH " );
     }
 
+    KConfigGroup grp( kapp->config(), "MakeOutputView" );
+    if( grp.readBoolEntry( "ForceCLocale", true ) )
+        environstr += "LC_MESSAGES="+EnvVarTools::quote("C")+" "+" "+"LC_CTYPE="+EnvVarTools::quote("C")+" ";
+
     return environstr;
 }
 
@@ -271,7 +277,7 @@ void TrollProjectPart::projectConfigWidget(KDialogBase *dlg)
     MakeOptionsWidget *w4 = new MakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
 
     vbox = dlg->addVBoxPage(i18n("QMake Manager"), i18n("QMake Manager"), BarIcon( "make", KIcon::SizeMedium ));
-    QMakeOptionsWidget *qm = new QMakeOptionsWidget(*projectDom(), "/kdevtrollproject", vbox);
+    QMakeOptionsWidget *qm = new QMakeOptionsWidget( projectDirectory(), *projectDom(), "/kdevtrollproject", vbox);
 
 
     connect( dlg, SIGNAL(okClicked()), w4, SLOT(accept()) );
@@ -508,7 +514,7 @@ QString TrollProjectPart::mainProgram() const
 
     QDomDocument &dom = *projectDom();
 
-    if( DomUtil::readBoolEntry(dom, "/kdevtrollproject/run/useglobalprogram", true) )
+    if( DomUtil::readBoolEntry(dom, "/kdevtrollproject/run/useglobalprogram", false) )
     {
         QString DomMainProgram = DomUtil::readEntry(dom, "/kdevtrollproject/run/mainprogram");
 
