@@ -95,6 +95,9 @@ public:
     enum SaveType { AlwaysSave, NeverSave, Ask };
     QMakeScopeItem* currentSubproject();
 
+    bool showFilenamesOnly() const;
+    bool showVariablesInTree() const;
+
 public slots:
     void slotBuildTarget();
     void slotInstallTarget();
@@ -148,7 +151,7 @@ private:
     GroupItem* getInstallRoot( QMakeScopeItem *item );
     GroupItem* getInstallObject( QMakeScopeItem *item, const QString& objectname );
     QString constructMakeCommandLine( Scope* s = 0 );
-    void startMakeCommand( const QString &dir, const QString &target );
+
     void createMakefileIfMissing( const QString &dir, QMakeScopeItem *item );
 
     void runQMakeRecursive( QMakeScopeItem* proj);
@@ -165,6 +168,7 @@ private:
     QMakeScopeItem *findSubprojectForScope( QMakeScopeItem *scope );
 
     void reloadProjectFromFile( QMakeScopeItem* item );
+    QMap<QString,QString> qmakeEnvironment() const;
 
     QVBox *overviewContainer;
     KListView *overview;
@@ -201,6 +205,8 @@ private:
     TrollProjectView m_lastFocusedView;
 
     bool m_filesCached;
+    bool m_showFilenamesOnly;
+    bool m_showVariablesInTree;
     QStringList m_allFilesCache;
 
     friend class ChooseSubprojectDlg;
