@@ -12,7 +12,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#ifndef QT_MAC
 #include "dbgtoolbar.h"
 #include "debuggerpart.h"
 #include "dbgcontroller.h"
@@ -203,7 +203,14 @@ QSize DbgButton::sizeHint() const
     if (text().isEmpty())
         return pixmap_.size();
     else
-        return QPushButton::sizeHint();
+    {
+        QSize ps = pixmap_.size();
+        QSize bs = QPushButton::sizeHint();
+        QSize result;
+        result.setWidth( ps.width() + bs.width()+10 );
+        result.setHeight( ps.height() > bs.height() ? ps.height() : bs.height() );
+        return result;
+    }
 }
 
 // **************************************************************************
@@ -274,7 +281,7 @@ DbgToolBar::DbgToolBar(DebuggerPart* part,
     // This widget is closed when the debugger finishes i.e. they press "Stop"
 
     // Do we need NoFocus???
-    KWin::setState(winId(), NET::StaysOnTop | NET::Modal | NET::SkipTaskbar);
+    KWin::setState(winId(), NET::StaysOnTop | NET::SkipTaskbar);
 //    KWin::setType(winId(), NET::Override);    // So it has no decoration
     KWin::setType(winId(), NET::Dock);
 
@@ -488,3 +495,4 @@ void DbgToolBar::slotActivateAndUndock()
 
 // **************************************************************************
 #include "dbgtoolbar.moc"
+#endif
