@@ -19,9 +19,15 @@
 #include <qhbox.h>
 #include <qpopupmenu.h>
 #include <qtable.h>
+#include <qguardedptr.h>
+#include <qvaluevector.h>
+
+#include "mi/gdbmi.h"
+#include "gdbcontroller.h"
 
 class QDomElement;
 class QToolButton;
+class QLabel;
 class KURL;
 
 /***************************************************************************/
@@ -33,13 +39,15 @@ namespace GDBDebugger
 class Breakpoint;
 class BreakpointTableRow;
 class GDBTable;
+class GDBController;
 
 class GDBBreakpointWidget : public QHBox
 {
     Q_OBJECT
 
 public:
-    GDBBreakpointWidget( QWidget* parent=0, const char* name=0 );
+    GDBBreakpointWidget( GDBController* controller,
+                         QWidget* parent=0, const char* name=0 );
     virtual ~GDBBreakpointWidget();
 
     void reset();
@@ -47,6 +55,8 @@ public:
     void savePartialProjectSession(QDomElement* el);
     void restorePartialProjectSession(const QDomElement* el);
 
+    bool hasWatchpointForAddress(unsigned long long address) const;
+
 
 public slots:
     // Connected to from the editor widget:
@@ -56,16 +66,14 @@ public slots:
     // Connected to from the variable widget:
     void slotToggleWatchpoint(const QString &varName);
 
-    // Connected to from the dbgcontroller:
-    void slotSetPendingBPs();
-    void slotUnableToSetBPNow(int BPNo);
-    void slotParseGDBBrkptList(char *str);
-    void slotParseGDBBreakpointSet(char *str, int BPKey);
+    void slotBreakpointSet(Breakpoint*);
 
     void slotRefreshBP(const KURL &filename);
+
+    void slotBreakpointHit(int id);
+
     
 protected:
-    enum BW_ITEMS { BW_ITEM_Show, BW_ITEM_Edit, BW_ITEM_Disable, BW_ITEM_Delete };
     virtual void focusInEvent(QFocusEvent *e);
 
 
@@ -75,19 +83,26 @@ private slots:
     void slotRemoveAllBreakpoints();
     void slotEditBreakpoint(const QString &fileName, int lineNum);
     void slotEditBreakpoint();
-    void slotAddBreakpoint();
     void slotAddBlankBreakpoint(int idx);
     void slotRowDoubleClicked(int row, int col, int button, const QPoint & mousePos);
     void slotContextMenuShow( int row, int col, const QPoint &mousePos );
     void slotContextMenuSelect( int item );
     void slotEditRow(int row, int col, const QPoint & mousePos);
     void slotNewValue(int row, int col);
+    void editTracing(QTableItem* item);
+    void slotBreakpointModified(Breakpoint*);
+
+    void slotEvent(GDBController::event_t);
+    void slotWatchpointHit(int id,
+                           const QString& oldValue,
+                           const QString& newValue);
 
 signals:
     void publishBPState(const Breakpoint& brkpt);
     void refreshBPState(const Breakpoint& brkpt);
     void gotoSourcePosition(const QString &fileName, int lineNum);
-    void clearAllBreakpoints();
+    // Emitted when output from yet another passed tracepoint is available.
+    void tracingOutput(const char*);
 
 private:
     BreakpointTableRow* find(Breakpoint *bp);
@@ -98,25 +113,34 @@ private:
     BreakpointTableRow* addBreakpoint(Breakpoint *bp);
     void removeBreakpoint(BreakpointTableRow* btr);
 
-private:
-    GDBTable*       m_table;
+    void sendToGdb(Breakpoint &);
 
-    QToolButton*    m_add;
-    QToolButton*    m_delete;
-    QToolButton*    m_edit;
-    QToolButton*    m_removeAll;
+    void handleBreakpointList(const GDBMI::ResultRecord&);
+    void handleTracingPrintf(const QValueVector<QString>& s);
+
+private:
+    GDBController*  controller_;
+
+    GDBTable*       m_table;
     QPopupMenu*     m_ctxMenu;
 };
 
 class BreakpointTableRow;
 
-/** Custom table cell class that add "..." button for editing the action. */
-class BreakpointActionCell : public QObject, public QTableItem
+/** Custom table cell class for cells that require complex editing.
+    When current, the cell shows a "..." on the right. When clicked,
+    the 'edit' signal is emitted that can be be used to pop-up
+    a dialog box. 
+
+    When editing is done, the receiver of 'edit' should change the
+    value in the table, and then call the 'updateValue' method.    
+ */
+class ComplexEditCell : public QObject, public QTableItem
 {
     Q_OBJECT
 public:
 
-    BreakpointActionCell(BreakpointTableRow* row, QTable* table);
+    ComplexEditCell(QTable* table);
 
     /** Called by Qt when the current cell should become editable.
         In our case, when the item becomes current. Creates a widget
@@ -126,14 +150,18 @@ public:
     */
     QWidget* createEditor() const;    
 
+    void updateValue();
+
 private slots:
 
     /** Called when the "..." button is clicked. */
     void slotEdit();
 
+signals:
+    void edit(QTableItem*);
+
 private:
-    mutable QWidget* editor_;
-    BreakpointTableRow* row_;
+    mutable QGuardedPtr<QLabel> label_;
 };
 
 
