@@ -291,11 +291,11 @@ void GDBController::queueCmd(GDBCommand *cmd, enum queue_where queue_where)
 {
     if (stateIsOn(s_dbgNotStarted))
     {
-        KMessageBox::error(
+        KMessageBox::information(
             0,
             i18n("<b>Gdb command sent when debugger is not running</b><br>"
             "The command was:<br> %1").arg(cmd->initialString()),
-            i18n("Internal error"));
+            i18n("Internal error"), "gdb_error");
         return;
     }
 
@@ -388,9 +388,9 @@ void GDBController::executeCmd()
     }
     if (bad_command)
     {
-        KMessageBox::error(0, i18n("<b>Invalid debugger command</b><br>")
+        KMessageBox::information(0, i18n("<b>Invalid debugger command</b><br>")
                            + message,
-                           i18n("Invalid debugger command"));
+                           i18n("Invalid debugger command"), "gdb_error");
         return;
     }
 
@@ -646,9 +646,12 @@ void GDBController::programNoApp(const QString &msg, bool msgBox)
     raiseEvent(program_exited);
 
     if (msgBox)
-        KMessageBox::error(0, i18n("gdb message:\n")+msg);
+        KMessageBox::information(0, i18n("gdb message:\n")+msg,"Warning", "gdb_error");
 
     emit dbgStatus (msg, state_);
+    /* Also show message in gdb window, so that users who
+       prefer to look at gdb window know what's up.  */
+    emit gdbUserCommandStdout(msg.ascii());
 }
 
 void GDBController::parseCliLine(const QString& line)
@@ -707,7 +710,7 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
         // FIXME: throw an exception here. Move reporting
         // to the caller, who knows the gdb output.
 #if 0
-        KMessageBox::error(
+        KMessageBox::information(
             0,
             i18n("Invalid gdb reply\n"
                  "Command was: %1\n"
@@ -716,7 +719,7 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
             .arg(currentCmd_->rawDbgCommand())
             .arg(buf)
             .arg(r.reason),
-            i18n("Invalid gdb reply"));
+            i18n("Invalid gdb reply"), "gdb_error");
 #endif
     }
 
@@ -824,7 +827,7 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
         emit gdbUserCommandStdout(
             QString( "/bin/sh -c " + shell + " " + gdb
                      + " " + application
-                     + " --interpreter=mi2 -quiet" ).latin1());
+                     + " --interpreter=mi2 -quiet\n" ).latin1());
     }
     else
     {
@@ -832,19 +835,19 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
                      << "-interpreter=mi2" << "-quiet";
         emit gdbUserCommandStdout(
             QString( gdb + " " + application +
-                     " --interpreter=mi2 -quiet" ).latin1());
+                     " --interpreter=mi2 -quiet\n" ).latin1());
     }
 
     if (!dbgProcess_->start( KProcess::NotifyOnExit,
                              KProcess::Communication(KProcess::All)))
     {
-        KMessageBox::error(
+        KMessageBox::information(
             0,
             i18n("<b>Could not start debugger.</b>"
                  "<p>Could not run '%1'. "
                  "Make sure that the path name is specified correctly."
                 ).arg(dbgProcess_->args()[0]),
-            i18n("Could not start debugger"));
+            i18n("Could not start debugger"), "gdb_error");
 
         return false;
     }
@@ -852,6 +855,8 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     setStateOff(s_dbgNotStarted);
     emit dbgStatus ("", state_);
 
+    saw_gdb_prompt_ = false;
+
     // Initialise gdb. At this stage gdb is sitting wondering what to do,
     // and to whom. Organise a few things, then set up the tty for the application,
     // and the application itself
@@ -870,18 +875,6 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     queueCmd(new GDBCommand("set width 0"));
     queueCmd(new GDBCommand("set height 0"));
 
-    // Get gdb to notify us of shared library events. This allows us to
-    // set breakpoints in shared libraries that are not loaded yet. On each
-    // stop, we'll try to set breakpoints again.
-    //
-    // Gdb 6.3 and later implement so called 'pending breakpoints' that
-    // solve this issue cleanly, but:
-    // - This is broken for MI -break-insert command (the breakpoint is
-    //   not inserted at all, and no error is produced)
-    // - MI does not contains notification that pending breakpoint is resolved.
-    queueCmd(new GDBCommand("set stop-on-solib-events 1"));
-
-
     queueCmd(new GDBCommand("handle SIG32 pass nostop noprint"));
     queueCmd(new GDBCommand("handle SIG41 pass nostop noprint"));
     queueCmd(new GDBCommand("handle SIG42 pass nostop noprint"));
@@ -922,11 +915,12 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
         queueCmd(new GDBCommand(environstr.latin1()));
     }
 
-    // Needed so that breakpoint widget has a chance to insert breakpoints.
-    // FIXME: a bit hacky, as we're really not ready for new commands.
-    setStateOn(s_dbgBusy);
-    raiseEvent(debugger_ready);
-    raiseEvent(connected_to_program);
+    queueCmd(new GDBCommand(
+                 "-list-features", this,
+                 &GDBController::handleListFeatures, true /* handles error */));
+
+ 
+    queueCmd(new SentinelCommand(this, &GDBController::startDone));
 
     // Now gdb has been started and the application has been loaded,
     // BUT the app hasn't been started yet! A run command is about to be issued
@@ -936,6 +930,37 @@ bool GDBController::start(const QString& shell, const DomUtil::PairList& run_env
     return true;
 }
 
+void GDBController::startDone()
+{
+   // Needed so that breakpoint widget has a chance to insert breakpoints.
+    // FIXME: a bit hacky, as we're really not ready for new commands.
+    setStateOn(s_dbgBusy);
+    raiseEvent(debugger_ready);
+    raiseEvent(connected_to_program);
+}
+
+void GDBController::handleListFeatures(const GDBMI::ResultRecord& r)
+{
+    mi_pending_breakpoints_ = false;
+    if (r.reason == "done")
+    {
+        const GDBMI::Value& features = r["features"];
+        for (unsigned i = 0; i < features.size(); ++i)
+            if (features[i].literal() == "pending-breakpoints")
+            {
+                mi_pending_breakpoints_ = true;
+            }
+    }
+
+    if (!mi_pending_breakpoints_)
+    {
+        // This version of GDB does not support pending breakpoints in MI,
+        // so use a workaround.
+        // The below command makes GDB notify us about shared library
+        // events, and on each stop we'll try to set breakpoint again.
+        addCommandToFront(new GDBCommand("set stop-on-solib-events 1"));
+    }
+}
 // **************************************************************************
 
 void GDBController::slotStopDebugger()
@@ -1083,11 +1108,11 @@ void GDBController::slotRun()
         QString tty(tty_->getSlave());
         if (tty.isEmpty())
         {
-            KMessageBox::error(0, i18n("GDB cannot use the tty* or pty* devices.\n"
+            KMessageBox::information(0, i18n("GDB cannot use the tty* or pty* devices.\n"
                                        "Check the settings on /dev/tty* and /dev/pty*\n"
                                        "As root you may need to \"chmod ug+rw\" tty* and pty* devices "
                                        "and/or add the user to the tty group using "
-                                       "\"usermod -G tty username\"."));
+                                       "\"usermod -G tty username\"."), "Warning",  "gdb_error");
 
             delete tty_;
             tty_ = 0;
@@ -1157,7 +1182,9 @@ void GDBController::slotRun()
             }
             else
             {
-                queueCmd(new GDBCommand("-exec-run"));
+                GDBCommand *cmd = new GDBCommand("-exec-run");
+                cmd->setRun(true);
+                queueCmd(cmd);
             }
         }
     }
@@ -1330,12 +1357,12 @@ void GDBController::defaultErrorHandler(const GDBMI::ResultRecord& result)
         return;
     }
 
-    KMessageBox::error(
+    KMessageBox::information(
         0,
         i18n("<b>Debugger error</b>"
              "<p>Debugger reported the following error:"
              "<p><tt>") + result["msg"].literal(),
-        i18n("Debugger error"));
+        i18n("Debugger error"), "gdb_error");
 
     // Error most likely means that some change made in GUI
     // was not communicated to the gdb, so GUI is now not
@@ -1516,7 +1543,15 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
             case GDBMI::Record::Stream: {
 
                 GDBMI::StreamRecord& s = dynamic_cast<GDBMI::StreamRecord&>(*r);
-                if (!currentCmd_ || currentCmd_->isUserCommand())
+                /* The way current code works is that we start gdb,
+                   and immediately send commands to it without waiting for
+                   a prompt.  As result, when we return back to the event
+                   loop and read the first line from GDB, currentCmd_ is
+                   already set.  But really, we want to output everything
+                   that gdb prints prior to prompt -- it might be
+                   output from user's .gdbinit that user cares about.  */
+                if (!saw_gdb_prompt_ 
+                    || !currentCmd_ || currentCmd_->isUserCommand())
                     emit gdbUserCommandStdout(s.message.ascii());
                 else
                     emit gdbInternalCommandStdout(s.message.ascii());
@@ -1526,7 +1561,6 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
 
                 parseCliLine(s.message);
 
-
                 static QRegExp print_output("^\\$(\\d+) = ");
                 if (print_output.search(s.message) != -1)
                 {
@@ -1534,11 +1568,17 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
                     print_command_result = s.message.ascii();
                 }
 
+                /* This is output from the program.  Route it to
+                   the Application window.  */
+                if (s.reason == '@')
+                    emit ttyStderr(s.message.ascii());
+
                 break;
             }
 
 
             case GDBMI::Record::Prompt:
+                saw_gdb_prompt_ = true;
                 break;
             }
         }
@@ -1608,7 +1648,7 @@ void GDBController::removeStateReloadingCommands()
     {
         i--;
         GDBCommand* cmd = cmdList_.at(i);
-        if (stateReloadingCommands_.count(cmd));
+        if (stateReloadingCommands_.count(cmd))
         {
             kdDebug(9012) << "UNQUEUE: " << cmd->initialString() << "\n";
             delete cmdList_.take(i);
@@ -1767,7 +1807,7 @@ void GDBController::debugStateChange(int oldState, int newState)
 
                 bool found = false;
 #define STATE_CHECK(name)\
-    if (i == name) { out += #name; found = true; } else
+    if (i == name) { out += #name; found = true; }
                 STATE_CHECK(s_dbgNotStarted);
                 STATE_CHECK(s_appNotStarted);
                 STATE_CHECK(s_waitForWrite);
@@ -1806,6 +1846,11 @@ void GDBController::demandAttention() const
     }
 }
 
+bool GDBController::miPendingBreakpoints() const
+{
+    return mi_pending_breakpoints_;
+}
+
 }
 
 // **************************************************************************
