@@ -758,12 +758,12 @@ void VariableTree::frameIdReady(const QValueVector<QString>& lines)
     }
     else
     {
-        KMessageBox::warningYesNo(
+        KMessageBox::information(
             0,
             "<b>Can't get frame id</b>"
             "Could not found frame id from output of 'info frame'. "
             "Further debugging can be unreliable. ",
-            i18n("Internal error"), KStdGuiItem::ok(), KStdGuiItem::cont(), "gdb_error");
+            i18n("Internal error"),  "gdb_error");
     }
 
     if (frameIdChanged)
@@ -895,10 +895,10 @@ void VarItem::handleCliPrint(const QValueVector<QString>& lines)
         {
             // FIXME: merge all output lines together.
             // FIXME: add 'debuggerError' to debuggerpart.
-            KMessageBox::warningYesNo(
+            KMessageBox::information(
                 0,
                 i18n("<b>Debugger error</b><br>") + lines[1],
-                i18n("Debugger error"), KStdGuiItem::ok(), KStdGuiItem::cont(), "gdb_error");
+                i18n("Debugger error"), "gdb_error");
         }
     }
 }
@@ -1272,8 +1272,8 @@ void VarItem::valueDone(const GDBMI::ResultRecord& r)
                     encoded += c;
                 else {
                     // Try common escape characters.
-                    static char *backslashed[] = {"a", "b", "f", "n",
-                                                  "r", "t", "v", "0"};
+                    static char backslashed[] = {'a', 'b', 'f', 'n',
+                                                  'r', 't', 'v', '0'};
                     static char represented[] = "\a\b\f\n\r\t\v";
 
                     const char* ix = strchr (represented, c);
@@ -1708,7 +1708,8 @@ bool VarItem::handleSpecialTypes()
     if (qstring.exactMatch(originalValueType_)) {
 
         VariableTree* varTree = static_cast<VariableTree*>(listView());
-
+        if( !varTree->controller() )
+            return false;
         varTree->controller()->addCommand(
             new ResultlessCommand(QString("print $kdev_d=%1.d")
                                   .arg(gdbExpression()),
