@@ -14,6 +14,7 @@
 #include "ast_utils.h"
 #include "cpp_tags.h"
 #include "doxydoc.h"
+#include "driver.h" 
 
 #include <kdebug.h>
 #include <qfileinfo.h>
@@ -66,6 +67,27 @@ void TagCreator::parseTranslationUnit( const ParsedFile& ast )
 	m_inClass = false;
 	
 	m_imports << QStringList();
+
+  	Tag tag;
+  	tag.setKind( Tag::Kind_TranslationUnit );
+  	tag.setFileName( m_fileName );
+  	tag.setName( m_fileName );
+
+	QByteArray data;
+	QDataStream stream(data, IO_WriteOnly );
+	ast.write( stream );
+	tag.setAttribute( "cppparsedfile", data );
+	tag.setAttribute( "includedFrom", ast.includedFrom() );
+	tag.setAttribute( "skippedLines", QString("%1").arg( ast.skippedLines()) );
+	tag.setAttribute( "macroValueHash", QString("%1").arg( ast.usedMacros().valueHash()) );
+	tag.setAttribute( "macroIdHash", QString("%1").arg( ast.usedMacros().idHash() ) );
+	
+  	tag.setScope( m_currentScope );
+  	if( !ast->comment().isEmpty() )
+		tag.setComment( ast->comment() );
+	  
+  	m_catalog->addItem( tag );
+	
 	TreeParser::parseTranslationUnit( ast );
 	m_imports.pop_back();
 }
@@ -799,8 +821,6 @@ void TagCreator::parseBaseClause( const QString& className, BaseClauseAST * base
 		tagBuilder.setVirtual( isVirtual );
 		tagBuilder.setAccess( TagUtils::stringToAccess( access ) );
 		
-		m_catalog->addItem( tag );
-		
 		int line, col;
 		baseClause->getStartPosition( &line, &col );
 		tag.setStartPosition( line, col );
@@ -808,7 +828,9 @@ void TagCreator::parseBaseClause( const QString& className, BaseClauseAST * base
 		baseClause->getEndPosition( &line, &col );
 		tag.setEndPosition( line, col );
 		
-		++it;
+        m_catalog->addItem( tag );
+		
+        ++it;
 	}
 }
 
