@@ -613,6 +613,21 @@ TypeDesc& TypeDesc::makePrivate() {
   return *this;
 }
 
+int TypeDesc::totalPointerDepth() const {
+  if( next() )
+    return next()->totalPointerDepth();
+  else
+    return pointerDepth();
+}
+
+void TypeDesc::setTotalPointerDepth( int d ) {
+  makePrivate();
+  if( next() )
+    next()->setTotalPointerDepth( d );
+  else
+    setPointerDepth( d );
+}
+
 void TypeDesc::maybeInit() {
   if ( m_data )
     return ;
@@ -659,11 +674,39 @@ void TypeDesc::init( QString stri ) {
     m_data->m_functionDepth++;
     str = str.mid( strlen( functionMark ) ).stripWhiteSpace();
   }
-	bool isFunction = false;
+	bool isFunction = false, shorten = true;
 
-	if( str.startsWith( "operator " ) ) isFunction = true;
+        //Little hack done for performance-reasons, to do less comparing
+        if( str.length() >= 4 ) {
+          QChar c = str[0];
+          switch( c.latin1() ) {
+          case 's':
+            if( str[1] == 'h' ) {
+              if( str.startsWith( "short" ) )
+                shorten = false;
+            } else if( str[1] == 'i' ) {
+              if( str.startsWith( "signed" ) )
+                shorten = false;
+            }
+            break;
+          case 'l':
+            if( str.startsWith( "long" ) )
+              shorten = false;
+            break;
+          case 'u':
+            if( str.startsWith( "unsigned" ) )
+              shorten = false;
+            break;
+          case 'o':
+            if( str.startsWith( "operator " ) ) {
+              isFunction = true;
+              shorten = false;
+            }
+          }
+        }
+        
 	///Since function-names are also processed by this function, this check has to be done
-	if( !isFunction ) {
+	if( shorten ) {
   ///Remove any prefixes like const or typename(very limited algorithm)
 		int len = str.find( "<" );
 		if ( len == -1 )
@@ -674,10 +717,8 @@ void TypeDesc::init( QString stri ) {
 			if ( str[ a ] == ' ' ) {
 				wasEmpty = true;
 			} else if( wasEmpty && isValidIdentifierSign( str[a] ) ){
-				//if ( wasEmpty ) {
-					currentStart = a;
-					wasEmpty = false;
-				//}
+                                currentStart = a;
+                                wasEmpty = false;
 			}
 		}
 		str = str.mid( currentStart );
@@ -716,7 +757,7 @@ void TypeDesc::init( QString stri ) {
 #else
 	if( !isFunction ) {
   	takeData( str );
-  	m_data->m_pointerDepth = countExtract( '*', str );
+    m_data->m_pointerDepth = countExtract( '*', str );
 	} else {
 		m_data->m_cleanName = str;
 	}
