@@ -38,12 +38,18 @@ private slots:
     void addedFilesToProject(const QStringList &fileList);
     void removedFilesFromProject(const QStringList &fileList);
     void slotRun();
+    void slotRunTestUnderCursor();
     void slotCreateSubclass();
     void contextMenu(QPopupMenu *popup, const Context *context);
     void slotBrowse();
 
     void initialParse();
 
+    void slotSwitchToController();
+    void slotSwitchToView();
+    void slotSwitchToModel();
+    void slotSwitchToTest();
+
 private:
     void startApplication(const QString &program);
     QString interpreter();
