@@ -3,12 +3,15 @@
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: CircularQueue.hpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include <antlr/config.hpp>
+#include <antlr/Token.hpp>
 #include <vector>
+#include <cassert>
 
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 namespace antlr {
@@ -21,7 +24,8 @@ template <class T>
 class ANTLR_API CircularQueue {
 public:
 	CircularQueue()
-	: storage(), m_offset(0)
+	: storage()
+	, m_offset(0)
 	{
 	}
 	~CircularQueue()
@@ -35,8 +39,8 @@ public:
 		storage.clear();
 	}
 
-	/// @todo this should use at or
-	inline T elementAt(int idx) const
+	/// @todo this should use at or should have a check
+	inline T elementAt( size_t idx ) const
 	{
 		return storage[idx+m_offset];
 	}
@@ -50,28 +54,40 @@ public:
 		else
 			++m_offset;
 	}
-	inline void removeItems( int nb )
+	inline void removeItems( size_t nb )
 	{
+		// it would be nice if we would not get called with nb > entries
+		// (or to be precise when entries() == 0)
+		// This case is possible when lexer/parser::recover() calls
+		// consume+consumeUntil when the queue is empty.
+		// In recover the consume says to prepare to read another
+		// character/token. Then in the subsequent consumeUntil the
+		// LA() call will trigger
+		// syncConsume which calls this method *before* the same queue
+		// has been sufficiently filled.
+		if( nb > entries() )
+			nb = entries();
+
 		if (m_offset >= OFFSET_MAX_RESIZE)
 		{
 			storage.erase( storage.begin(), storage.begin() + m_offset + nb );
 			m_offset = 0;
 		}
 		else
-			m_offset+=nb;
+			m_offset += nb;
 	}
 	inline void append(const T& t)
 	{
 		storage.push_back(t);
 	}
-	inline int entries() const
+	inline size_t entries() const
 	{
-		return storage.size()-m_offset;
+		return storage.size() - m_offset;
 	}
 
 private:
-	typename ANTLR_USE_NAMESPACE(std)vector<T> storage;
-	int m_offset;
+	ANTLR_USE_NAMESPACE(std)vector<T> storage;
+	size_t m_offset;
 
 	CircularQueue(const CircularQueue&);
 	const CircularQueue& operator=(const CircularQueue&);
