@@ -3,8 +3,9 @@
 
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: TokenBuffer.hpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include <antlr/config.hpp>
@@ -25,7 +26,7 @@ namespace antlr {
  * token is not done by conume(), but deferred until needed by LA or LT.
  * <p>
  *
- * @todo see if we can integrate this one with InputBuffer into one template
+ * @todo: see if we can integrate this one with InputBuffer into one template
  * or so.
  *
  * @see antlr.Token
@@ -36,6 +37,7 @@ class ANTLR_API TokenBuffer {
 public:
 	/** Create a token buffer */
 	TokenBuffer(TokenStream& input_);
+	virtual ~TokenBuffer();
 
 	/// Reset the input buffer to empty state
 	inline void reset( void )
@@ -47,47 +49,50 @@ public:
 	}
 
 	/** Get a lookahead token value */
-	int LA(int i);
+	int LA( unsigned int i );
 
 	/** Get a lookahead token */
-	RefToken LT(int i);
+	RefToken LT( unsigned int i );
 
 	/** Return an integer marker that can be used to rewind the buffer to
 	 * its current state.
 	 */
-	int mark();
+	unsigned int mark();
 
 	/**Rewind the token buffer to a marker.
 	 * @param mark Marker returned previously from mark()
 	 */
-	void rewind(int mark);
+	void rewind(unsigned int mark);
 
 	/** Mark another token for deferred consumption */
 	inline void consume()
 	{
 		numToConsume++;
 	}
+
+	/// Return the number of entries in the TokenBuffer
+	virtual unsigned int entries() const;
+
 private:
 	/** Ensure that the token buffer is sufficiently full */
-	void fill(int amount);
+	void fill(unsigned int amount);
 	/** Sync up deferred consumption */
 	void syncConsume();
 
 protected:
-	// Token source
+	/// Token source
 	TokenStream& input;
 
-private:
-	// Number of active markers
-	int nMarkers;
+	/// Number of active markers
+	unsigned int nMarkers;
 
-	// Additional offset used when markers are active
-	int markerOffset;
+	/// Additional offset used when markers are active
+	unsigned int markerOffset;
 
-	// Number of calls to consume() since last LA() or LT() call
-	int numToConsume;
+	/// Number of calls to consume() since last LA() or LT() call
+	unsigned int numToConsume;
 
-	// Circular queue
+	/// Circular queue with Tokens
 	CircularQueue<RefToken> queue;
 
 private:
