@@ -1,8 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: CommonToken.cpp,v 1.2 2003/05/02 00:36:20 okellogg Exp $
+ * $Id: CommonToken.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include "antlr/CommonToken.hpp"
@@ -16,16 +16,22 @@ CommonToken::CommonToken() : Token(), line(1), col(1), text("")
 {}
 
 CommonToken::CommonToken(int t, const ANTLR_USE_NAMESPACE(std)string& txt)
-	: Token(t), line(1), col(1), text(txt)
+: Token(t)
+, line(1)
+, col(1)
+, text(txt)
 {}
 
 CommonToken::CommonToken(const ANTLR_USE_NAMESPACE(std)string& s)
-	: Token(), line(1), col(1), text(s)
+: Token()
+, line(1)
+, col(1)
+, text(s)
 {}
 
 ANTLR_USE_NAMESPACE(std)string CommonToken::toString() const
 {
-	return "[\""+getText()+"\",<"+type+">,line="+line+",column="+col+"]";
+	return "[\""+getText()+"\",<"+getType()+">,line="+getLine()+",column="+getColumn()+"]";
 }
 
 RefToken CommonToken::factory()
