@@ -1,7 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: InputBuffer.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include "antlr/config.hpp"
@@ -12,7 +13,7 @@ namespace antlr {
 #endif
 
 /** Ensure that the character buffer is sufficiently full */
-void InputBuffer::fill(int amount)
+void InputBuffer::fill(unsigned int amount)
 {
 	syncConsume();
 	// Fill the buffer sufficiently to hold needed characters
@@ -30,7 +31,7 @@ ANTLR_USE_NAMESPACE(std)string InputBuffer::getLAChars( void ) const
 {
 	ANTLR_USE_NAMESPACE(std)string ret;
 
-	for(int i = markerOffset; i < queue.entries(); i++)
+	for(unsigned int i = markerOffset; i < queue.entries(); i++)
 		ret += queue.elementAt(i);
 
 	return ret;
@@ -43,7 +44,7 @@ ANTLR_USE_NAMESPACE(std)string InputBuffer::getMarkedChars( void ) const
 {
 	ANTLR_USE_NAMESPACE(std)string ret;
 
-	for(int i = 0; i < markerOffset; i++)
+	for(unsigned int i = 0; i < markerOffset; i++)
 		ret += queue.elementAt(i);
 
 	return ret;
@@ -52,7 +53,7 @@ ANTLR_USE_NAMESPACE(std)string InputBuffer::getMarkedChars( void ) const
 /** Return an integer marker that can be used to rewind the buffer to
  * its current state.
  */
-int InputBuffer::mark()
+unsigned int InputBuffer::mark()
 {
 	syncConsume();
 	nMarkers++;
@@ -62,13 +63,19 @@ int InputBuffer::mark()
 /** Rewind the character buffer to a marker.
  * @param mark Marker returned previously from mark()
  */
-void InputBuffer::rewind(int mark)
+void InputBuffer::rewind(unsigned int mark)
 {
 	syncConsume();
 	markerOffset = mark;
 	nMarkers--;
 }
 
+unsigned int InputBuffer::entries() const
+{
+	//assert(queue.entries() >= markerOffset);
+	return queue.entries() - markerOffset;
+}
+
 #ifdef ANTLR_CXX_SUPPORTS_NAMESPACE
 }
 #endif
