@@ -1,7 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
+ * $Id: Token.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 
 #include "antlr/Token.hpp"
@@ -11,26 +12,6 @@
 namespace antlr {
 #endif
 
-// The below initialization ICED AIX Visualage CC
-//ANTLR_API RefToken Token::badToken(new Token(Token::INVALID_TYPE, "<no text>"));
-// this seemed to work
-ANTLR_API RefToken Token::badToken = RefToken(new Token(Token::INVALID_TYPE, "<no text>"));
-
-Token::Token() : type(INVALID_TYPE)
-{
-}
-
-Token::Token(int t) : type(t)
-{
-}
-
-Token::Token(int t, const ANTLR_USE_NAMESPACE(std)string& txt)
-	: type(t)
-{
-	type=t;
-	setText(txt);
-}
-
 int Token::getColumn() const
 {
 	return 0;
@@ -51,18 +32,32 @@ int Token::getType() const
 	return type;
 }
 
-void Token::setColumn(int /*c*/)
-{}
+void Token::setColumn(int)
+{
+}
 
-void Token::setLine(int /*l*/)
-{}
+void Token::setLine(int)
+{
+}
 
-void Token::setText(const ANTLR_USE_NAMESPACE(std)string& /*t*/)
-{}
+void Token::setText(const ANTLR_USE_NAMESPACE(std)string&)
+{
+}
 
 void Token::setType(int t)
 {
-	type=t;
+	type = t;
+}
+
+void Token::setFilename(const ANTLR_USE_NAMESPACE(std)string&)
+{
+}
+
+ANTLR_USE_NAMESPACE(std)string emptyString("");
+
+const ANTLR_USE_NAMESPACE(std)string& Token::getFilename() const
+{
+	return emptyString;
 }
 
 ANTLR_USE_NAMESPACE(std)string Token::toString() const
@@ -70,9 +65,6 @@ ANTLR_USE_NAMESPACE(std)string Token::toString() const
 	return "[\""+getText()+"\",<"+type+">]";
 }
 
-Token::~Token()
-{}
-
 ANTLR_API RefToken nullToken;
 
 #ifndef NO_STATIC_CONSTS
