@@ -142,8 +142,13 @@ void Lexer::setSource( const QString& source )
     tokenize();
 }
 
+int Lexer::skippedLines() const {
+  return m_skippedLines;
+}
+
 void Lexer::reset()
 {
+    m_skippedLines = 0;
     m_index = 0;
     m_size = 0;
     m_tokens.clear();
@@ -240,6 +245,7 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
             Token tok(m_source);
             nextToken( tok, true );
         }
+        ++m_skippedLines;
         m_startLine = true;
         setPreprocessorEnabled( ppe );
         return;
@@ -292,11 +298,10 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 	    int svLine = currentLine();
 	    int svColumn = currentColumn();
 
-//	    Macro& m = m_driver->macro( ide );
-	    Macro m = m_driver->macro( ide );
-            m_driver->usingMacro( m, m_currentLine, m_currentColumn );
+       Macro m = m_driver->macro( ide );
+       m_driver->usingMacro( m );
 
-            QString ellipsisArg;
+       QString ellipsisArg;
 
 	    if( m.hasArguments() ){
                 int endIde = currentPosition();
@@ -360,7 +365,8 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
 
             QString textToInsert;
 
-            m_endPtr = offset( currentPosition() + m.body().length() );
+            setEndPtr( offset( currentPosition() + m.body().length() ) );
+            
             while( currentChar() ){
 
                 readWhiteSpaces();
@@ -397,11 +403,11 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
                     textToInsert.append( str.str() + QString::fromLatin1(" ") );
                 }
             }
-
+        
 #if defined( KDEVELOP_BGPARSER )
 	    qthread_yield();
 #endif
-            insertCurrent( textToInsert );
+        insertCurrent( textToInsert ); //also corrects the end-pointer
 
             d->endScope();
             m_preprocessorEnabled = preproc;
@@ -631,14 +637,16 @@ int Lexer::macroDefined()
     m_driver->usingString( word );
     bool r = m_driver->hasMacro( word );
 
-    if( r ) m_driver->usingMacro( m_driver->macro( word ), m_currentLine, m_currentColumn );
-    
+    if( r ) m_driver->usingMacro( m_driver->macro( word ) );
+
     return r;
 }
 
 void Lexer::processDefine( Macro& m )
 {
     m.setFileName( m_driver->currentFileName() );
+    m.setLine( m_currentLine );
+    m.setColumn( m_currentColumn );
     readWhiteSpaces( false );
 
     int startMacroName = currentPosition();
@@ -860,7 +868,7 @@ int Lexer::macroPrimary()
                 HashedString h( tk.text() );
                 m_driver->usingString( h );
                 if( m_driver->hasMacro( h ) ) {
-                    m_driver->usingMacro( m_driver->macro( h ), m_currentLine, m_currentColumn );
+                    m_driver->usingMacro( m_driver->macro( h ) );
                     return true;
                 } else {
                     return false;
