@@ -20,19 +20,19 @@
 
 #include "lookup.h"
 
-int Lookup::find( const QString& s )
+int Lookup::find( const HashedString& s )
 {
     KeywordMap::const_iterator it = keywords().find( s );
     if( it == keywords().end() )
         return -1;
-    return static_cast<int>(it.data());
+    return static_cast<int>((*it).second);
 }
 
 const Lookup::KeywordMap& Lookup::keywords()
 {
     static KeywordMap keywords;
     
-    if( keywords.isEmpty() )
+    if( keywords.empty() )
     {
 #include "keywords.h"
     }
