@@ -177,6 +177,7 @@ bool HashedStringSet::operator[] ( const HashedString& rhs ) const {
 }
 
 void HashedStringSet::insert( const HashedString& str ) {
+  if( str.str().isEmpty() ) return;
   makeDataPrivate();
   m_data->m_files.insert( str );
   m_data->invalidateHash();
@@ -191,8 +192,8 @@ bool HashedStringSet::operator <= ( const HashedStringSet& rhs ) const {
     return false;
 #ifndef USE_HASHMAP
   return std::includes( rhs.m_data->m_files.begin(), rhs.m_data->m_files.end(), m_data->m_files.begin(), m_data->m_files.end() );
-#esle
-  HashedStringSetData::StringSet& otherSet( rhs.m_data->m_files );
+#else
+  const HashedStringSetData::StringSet& otherSet( rhs.m_data->m_files );
   HashedStringSetData::StringSet::const_iterator end = rhs.m_data->m_files.end();
   HashedStringSetData::StringSet::const_iterator myEnd = m_data->m_files.end();
 
@@ -282,3 +283,80 @@ QDataStream& operator >> ( QDataStream& stream, HashedString& str ) {
     stream >> str.m_hash;
     return stream;
 }
+
+void HashedStringSetGroup::addSet( size_t id, const HashedStringSet& set ) {
+  if( set.m_data && !set.m_data->m_files.empty() ) {
+    m_sizeMap[ id ] = set.size();
+    for( HashedStringSetData::StringSet::const_iterator it = set.m_data->m_files.begin(); it != set.m_data->m_files.end(); ++it ) {
+      GroupMap::iterator itr = m_map.find( *it );
+      if( itr == m_map.end() ) {
+        itr = m_map.insert( std::make_pair( *it, ItemSet() ) ).first;
+      }
+      itr->second.insert( id );
+    }
+  } else {
+    m_global.insert( id );
+  }
+}
+
+void HashedStringSetGroup::disableSet( size_t id ) {
+  m_disabled.insert( id );
+}
+
+void HashedStringSetGroup::enableSet( size_t id ) {
+  m_disabled.erase( id );
+}
+
+bool HashedStringSetGroup::isDisabled( size_t id ) const {
+  return m_disabled.find( id ) != m_disabled.end();
+}
+
+void HashedStringSetGroup::removeSet( size_t id ) {
+  m_disabled.erase( id );
+  m_global.erase( id );
+  m_sizeMap.erase( id );
+  for( GroupMap::iterator it = m_map.begin(); it != m_map.end(); ++it ) {
+    it->second.erase( id );
+  }
+}
+
+void HashedStringSetGroup::findGroups( HashedStringSet strings, ItemSet& target ) const {
+  target.clear();
+  if( !strings.m_data ) {
+    std::set_difference( m_global.begin(), m_global.end(), m_disabled.begin(), m_disabled.end(), std::insert_iterator<ItemSet>( target, target.end() ) );
+    return;
+  }
+  //This might yet be optimized by sorting the sets according to their size, and starting the intersectioning with the smallest ones.
+  __gnu_cxx::hash_map<size_t, int> hitCounts;
+  
+  for( HashedStringSetData::StringSet::const_iterator it = strings.m_data->m_files.begin(); it != strings.m_data->m_files.end(); ++it ) {
+    GroupMap::const_iterator itr = m_map.find( *it );
+      if( itr == m_map.end() ) {
+        //There are no string-sets that include the currently searched for string
+        continue;
+      }
+
+      for( ItemSet::const_iterator it2 = itr->second.begin(); it2 != itr->second.end(); ++it2 ) {
+        __gnu_cxx::hash_map<size_t, int>::iterator v = hitCounts.find( *it2 );
+        if( v != hitCounts.end() ) {
+          ++(*v).second;
+        } else {
+          hitCounts[*it2] = 1;
+        }
+      }
+  }
+
+  //Now count together all groups that are completely within the given string-set(their hitCount equals their size)
+  ItemSet found;
+  for( __gnu_cxx::hash_map<size_t, int>::const_iterator it = hitCounts.begin(); it != hitCounts.end(); ++it ) {
+    if( (*it).second == (*m_sizeMap.find( (*it).first )).second )
+      found.insert( (*it).first );
+  }
+
+  
+  std::set_union( found.begin(), found.end(), m_global.begin(), m_global.end(), std::insert_iterator<ItemSet>( target, target.end() ) );
+  
+  target.swap( found );
+  target.clear();
+  std::set_difference( found.begin(), found.end(), m_disabled.begin(), m_disabled.end(), std::insert_iterator<ItemSet>( target, target.end() ) );
+}
