@@ -15,9 +15,17 @@
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kstdguiitem.h>
+#include <kfile.h>
+#include <kfiledialog.h>
+#include <kurlrequesterdlg.h>
+#include <kurlrequester.h>
+#include <kmessagebox.h>
+#include <kdebug.h>
 
 #include <qlayout.h>
+#include <qfileinfo.h>
 #include <qlistview.h>
+#include <qapplication.h>
 #include <qsplitter.h>
 
 #include "kdevlanguagesupport.h"
@@ -30,7 +38,7 @@
 
 
 HierarchyDialog::HierarchyDialog( ClassViewPart *part )
-    : QDialog(0, "hierarchy dialog", WDestructiveClose)
+    : QDialog(0, "hierarchy dialog", false)
 {
     class_combo = new KComboView(true, 150, this);
     class_combo->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Preferred );
@@ -40,6 +48,8 @@ HierarchyDialog::HierarchyDialog( ClassViewPart *part )
 //    namespace_combo->setMinimumWidth(150);
 
     QPushButton *close_button = new KPushButton(KStdGuiItem::close(), this);
+    QPushButton *save_button = new KPushButton(KStdGuiItem::save(), this);
+    QPushButton *refresh_button = new KPushButton(i18n("Refresh"), this);
 
     QSplitter *splitter = new QSplitter(Vertical, this);
     digraph = new DigraphView(splitter, "digraph view");
@@ -51,6 +61,8 @@ HierarchyDialog::HierarchyDialog( ClassViewPart *part )
     combo_layout->addWidget(namespace_combo);
     combo_layout->addWidget(class_combo);
     combo_layout->addSpacing(60);
+    combo_layout->addWidget(refresh_button);
+    combo_layout->addWidget(save_button);
     combo_layout->addWidget(close_button);
     layout->addWidget(splitter);
 
@@ -58,8 +70,16 @@ HierarchyDialog::HierarchyDialog( ClassViewPart *part )
              this, SLOT(slotNamespaceComboChoice(QListViewItem*)) );
     connect( class_combo, SIGNAL(activated(QListViewItem*)),
              this, SLOT(slotClassComboChoice(QListViewItem*)) );
+    connect( namespace_combo, SIGNAL(textChanged(const QString&)),
+             this, SLOT(slotNamespaceComboChoice(const QString&)) );
+    connect( class_combo, SIGNAL(textChanged(const QString&)),
+             this, SLOT(slotClassComboChoice(const QString&)) );
     connect( close_button, SIGNAL(clicked()),
-             this, SLOT(reject()) );
+             this, SLOT(hide()) );
+    connect( save_button, SIGNAL(clicked()),
+             this, SLOT(save()) );
+    connect( refresh_button, SIGNAL(clicked()),
+             this, SLOT(refresh()) );
     connect( digraph, SIGNAL(selected(const QString&)),
              this, SLOT(classSelected(const QString&)) );
 
@@ -74,10 +94,43 @@ HierarchyDialog::~HierarchyDialog()
 //    m_part->unregisterHierarchyDialog(this);
 }
 
+void HierarchyDialog::save()
+{
+    KURLRequesterDlg dlg(QString::null, this, "save_inheritance");
+    dlg.fileDialog()->setFilter("image/png image/jpeg image/bmp image/svg+xml");
+    dlg.fileDialog()->setOperationMode( KFileDialog::Saving );
+    dlg.fileDialog()->setMode( KFile::File | KFile::LocalOnly );
+    dlg.urlRequester()->setMode( KFile::File | KFile::LocalOnly );
+    if(dlg.exec() && dlg.selectedURL().isLocalFile())
+    {
+	QFileInfo fi(dlg.selectedURL().pathOrURL());
+        QApplication::setOverrideCursor( Qt::waitCursor );
+        KDevLanguageSupport *ls = m_part->languageSupport();
+        for (QMap<QString, ClassDom>::const_iterator it = classes.begin(); it != classes.end(); ++it)
+        {
+            kdDebug(9003) << "Adding class to graph: " << it.key() << endl;
+            QString formattedName = ls->formatClassName(it.key());
+            QStringList baseClasses = it.data()->baseClassList();
+            for (QStringList::const_iterator bit = baseClasses.begin(); bit != baseClasses.end(); ++bit)
+            {
+                QMap<QString, QString>::const_iterator baseIt = uclasses.find(*bit);
+                if (baseIt != uclasses.end())
+                {
+                    QString formattedParentName = ls->formatClassName(baseIt.data());
+                    digraph->addEdge(formattedParentName, formattedName);
+                }
+            }
+        }
+        digraph->process(fi.absFilePath(), fi.extension());
+        QApplication::restoreOverrideCursor();
+    }
+}
 
 void HierarchyDialog::refresh()
 {
     digraph->clear();
+    classes.clear();
+    uclasses.clear();
     ViewCombosOp::refreshNamespaces(m_part, namespace_combo);
     processNamespace("", m_part->codeModel()->globalNamespace());
 
@@ -85,6 +138,7 @@ void HierarchyDialog::refresh()
 
     for (QMap<QString, ClassDom>::const_iterator it = classes.begin(); it != classes.end(); ++it)
     {
+        kdDebug(9003) << "Adding class to graph: " << it.key() << endl;
         QString formattedName = ls->formatClassName(it.key());
         QStringList baseClasses = it.data()->baseClassList();
         for (QStringList::const_iterator bit = baseClasses.begin(); bit != baseClasses.end(); ++bit)
@@ -123,6 +177,28 @@ void HierarchyDialog::slotClassComboChoice(QListViewItem * item)
     classSelected(className);
 }
 
+void HierarchyDialog::slotClassComboChoice( const QString& itemText )
+{
+    QListViewItem* item = class_combo->listView()->firstChild();
+    while( item )
+    {
+        if( item->text(0) == itemText )
+	{
+            ClassItem *ci = dynamic_cast<ClassItem*>(item);
+            if (!ci)
+                return;
+        
+            KDevLanguageSupport *ls = m_part->languageSupport();
+        
+            QString className = ls->formatClassName(uclasses[item->text(0)]);
+            digraph->setSelected(className);
+            digraph->ensureVisible(className);
+            classSelected(className);
+      	    return;
+	}
+	item = item->nextSibling();
+    }
+}
 
 void HierarchyDialog::classSelected(const QString &/*className*/)
 {
@@ -145,6 +221,23 @@ void HierarchyDialog::slotNamespaceComboChoice( QListViewItem * item )
     ViewCombosOp::refreshClasses(m_part, class_combo, ni->dom()->name());
 }
 
+void HierarchyDialog::slotNamespaceComboChoice( const QString& itemText )
+{
+    QListViewItem* item = namespace_combo->listView()->firstChild();
+    while( item )
+    {
+        if( item->text(0) == itemText )
+	{
+            NamespaceItem *ni = dynamic_cast<NamespaceItem*>(item);
+            if (!ni)
+                return;
+            ViewCombosOp::refreshClasses(m_part, class_combo, ni->dom()->name());
+	    return;
+	}
+	item = item->nextSibling();
+    }
+}
+
 void HierarchyDialog::processNamespace( QString prefix, NamespaceDom dom )
 {
     qWarning("processNamespace: prefix %s", prefix.latin1());
