@@ -40,11 +40,7 @@ ShellFilterDialog::ShellFilterDialog()
     KButtonBox *buttonbox = new KButtonBox(this);
     start_button = buttonbox->addButton(i18n("&Start"));
     start_button->setDefault(true);
-#if KDE_IS_VERSION( 3, 2, 90 )
     cancel_button = buttonbox->addButton(KStdGuiItem::cancel());
-#else
-    cancel_button = buttonbox->addButton(i18n("Cancel"));
-#endif
     buttonbox->layout();
     layout->addWidget(buttonbox);
 
