@@ -388,12 +388,20 @@ void GrepViewWidget::slotExecuted(QListBoxItem* item)
 }
 
 
-void GrepViewProcessWidget::insertStdoutLine(const QString &line)
+void GrepViewProcessWidget::insertStdoutLine(const QCString &line)
 {
 	int pos;
 	QString filename, linenumber, rest;
 
-	QString str = line;
+	QString str;
+        if( !grepbuf.isEmpty() )
+        {
+            str = QString::fromLocal8Bit( grepbuf+line );
+            grepbuf.truncate( 0 );
+        }else
+        {
+            str = QString::fromLocal8Bit( line );
+        }
 	if ( (pos = str.find(':')) != -1)
 	{
 		filename = str.left(pos);
@@ -518,5 +526,10 @@ void GrepViewProcessWidget::childFinished( bool normal, int status )
 	ProcessWidget::childFinished(normal, status);
 }
 
+void GrepViewProcessWidget::addPartialStdoutLine(const QCString & line)
+{
+    grepbuf += line;
+}
+
 
 #include "grepviewwidget.moc"
