@@ -2,6 +2,7 @@
 #define _CORE_H_
 
 #include <qregexp.h>
+#include <kxmlguiclient.h>
 
 #include <kparts/partmanager.h>
 
@@ -13,6 +14,9 @@ namespace MainWindowUtils{
 QString beautifyToolTip(const QString& text);
 }
 
+/**
+Core implementation.
+*/
 class Core : public KDevCore
 {
   Q_OBJECT
@@ -20,17 +24,25 @@ class Core : public KDevCore
 public:
 
   static Core *getInstance();
+  
+  /**
+   * Setup shourtcut tips. For every KAction with a shortcut,
+   * appends the shortcut string, in parenthesis, to the
+   * actions's tooltip. If tooltip already has any text in
+   * parens, it's removed and shortcut is added instead.
+   *
+   * @param client
+   *   Pointer to KXMLGUIClient object, which contain an collection
+   *   of actions (KActionCollection). If the parameter is null,
+   *   function is applied to the all available KXMLGUIClient objects.
+   */
+  static void setupShourtcutTips(KXMLGUIClient * client = 0);
 
   ~Core();
 
-  virtual void insertNewAction( KAction* action );
-
   virtual void running(KDevPlugin *which, bool runs);
   virtual void fillContextMenu(QPopupMenu *popup, const Context *context);
   virtual void openProject(const QString& projectFileName);
-  virtual QDict< KDevLicense > licenses();
-  
-  void loadLicenses();
 
   void doEmitProjectOpened() { emit projectOpened(); }
   void doEmitProjectClosed() { emit projectClosed(); }
@@ -53,9 +65,6 @@ protected:
 private:
   static Core *s_instance;
 
-private:
-  QDict< KDevLicense > m_licenses;
-  
 };
 
 
