@@ -31,11 +31,12 @@ public:
     virtual QString shortDescription() const
     { return i18n( "Perforce is a version control system" ); }
 
-    virtual void createNewProject(const QString& dir) {}
+    virtual void createNewProject(const QString& /* dir */) {}
     virtual bool fetchFromRepository() { return true; }
     virtual KDevVCSFileInfoProvider *fileInfoProvider() const { return 0; }
-    virtual bool isValidDirectory(const QString &dirPath) const { return true; }
-    
+    virtual bool isValidDirectory(const QString& /* dirPath*/) const
+    { return true; }
+
 private slots:
     void contextMenu(QPopupMenu *popup, const Context *context);
     void slotCommit();
